#ifndef CONTACTLISTVIEW_H
#define CONTACTLISTVIEW_H

#include <qcolor.h>
#include <qpixmap.h>
#include <qtooltip.h>
#include <qstring.h>

#include <klistview.h>

#include <kabc/field.h>

class KAddressBookTableView;
class ContactListView;
class ContactEntry;

class DynamicTip : public QToolTip
{
public:
    DynamicTip( ContactListView * parent );

protected:
    void maybeTip( const QPoint & );
};

class ContactListViewItem : public KListViewItem
{

public:
  ContactListViewItem(const QString &entryKey, ContactListView* parent, 
                      ContactEntryList *doc, const KABC::Field::List &fields );
  QString entryKey();
  ContactEntry *getEntry(); // will change name back to entry some time
  virtual void refresh();
  virtual ContactListView* parent();
  virtual QString key ( int, bool ) const;
  
  /** Adds the border around the cell if the user wants it
  */
  virtual void paintCell(QPainter * p, const QColorGroup & cg, 
                         int column, int width, int align );

private:
  QString mEntryKey;
  KABC::Field::List mFields;
  ContactListView *parentListView;
  ContactEntryList *mDocument;
};


/////////////////////////////////////////////
// ContactListView

class ContactListView : public KListView
{
  Q_OBJECT

friend class ContactListViewItem;
friend class KAddressBookTableView;

public:
  ContactListView(KAddressBookTableView *view, QWidget *parent, 
                  const char *name = 0L );
  virtual ~ContactListView() {}
  //void resort();
  
  /** Returns true if tooltips should be displayed, false otherwise
  */
  bool tooltips() const { return mToolTips; }
  void setToolTipsEnabled(bool enabled) { mToolTips = enabled; }
  
  bool alternateBackground() const { return mABackground; }
  void setAlternateBackgroundEnabled(bool enabled);
  
  bool singleLine() const { return mSingleLine; }
  void setSingleLineEnabled(bool enabled) { mSingleLine = enabled; }
  
  const QColor &alternateColor() const { return mAlternateColor; }
  
  /** Sets the background pixmap to <i>filename</i>. If the
  * QString is empty (QString::isEmpty()), then the background
  * pixmap will be disabled.
  */
  void setBackgroundPixmap(const QString &filename);
  
  KAddressBookTableView *getKAddressBookView();
  ContactListViewItem *getItem( const QString &entryKey );

protected:
  virtual void paintEmptyArea( QPainter * p, const QRect & rect );
  virtual void paletteChange( const QPalette & /*oldPalette*/ );
  virtual void contentsMousePressEvent(QMouseEvent*);
  void contentsMouseMoveEvent( QMouseEvent *e );
  void contentsDragEnterEvent( QDragEnterEvent *e );
  void contentsDropEvent( QDropEvent *e );

public slots:
  //void incSearch( const QString &value );
  //void setSorting( int column, bool ascending );
  //void setSorting( int column );
  //void loadBackground();
  //void readConfig();
  //void saveConfig();

private:
  KAddressBookTableView *pabWidget;
  int oldColumn;
  int column;
  bool ascending;

  bool mABackground;
  bool mSingleLine;
  bool mToolTips;

  QColor mAlternateColor;
  
//  bool backPixmapOn;
//  QString backPixmap;
//  QPixmap background;
//  QPixmap iBackground;
//  bool underline;
//  bool autUnderline;
//  bool tooltips_;
  QPoint presspos;
};


#endif
