/*                                                                      
    This file is part of KAddressBook.                                  
    Copyright (c) 2002 Mike Pilone <mpilone@slac.com>                   
                                                                        
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or   
    (at your option) any later version.                                 
                                                                        
    This program is distributed in the hope that it will be useful,     
    but WITHOUT ANY WARRANTY; without even the implied warranty of      
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the        
    GNU General Public License for more details.                        
                                                                        
    You should have received a copy of the GNU General Public License   
    along with this program; if not, write to the Free Software         
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.           
                                                                        
    As a special exception, permission is given to link this program    
    with any edition of Qt, and distribute the resulting executable,    
    without including the source code for Qt in the source distribution.
*/                                                                      

#include <klocale.h>

#include "importdialog.h"
#include "contactentry.h"
#include "contactentrylist.h"

ContactImportDialog::ContactImportDialog(ContactEntryList *list,
                                         QWidget *parent)
        : KImportDialog(parent), mList(list), mEntry(0)
{
    mFirstName = new KImportColumn(this,i18n("First Name"),1);
    mLastName = new KImportColumn(this,i18n("Last Name"),1);
//      mFullName = new KImportColumn(this,i18n("Full Name"));
    mEmail = new KImportColumn(this,i18n("Email"));
    mPhoneHome = new KImportColumn(this,i18n("Phone Home"));
    mPhoneBusiness = new KImportColumn(this,i18n("Phone Business"));
    mPhoneMobile = new KImportColumn(this,i18n("Phone Mobile"));
    mFaxHome = new KImportColumn(this,i18n("Fax Home"));
    mFaxBusiness = new KImportColumn(this,i18n("Fax Business"));
    mJobTitle = new KImportColumn(this,i18n("Job Title"));
    mCompany = new KImportColumn(this,i18n("Company"));

    mAddressHomeCity = new KImportColumn(this,i18n("Home Address City"));
    mAddressHomeStreet = new KImportColumn(this,i18n("Home Address Street"));
    mAddressHomeZip = new KImportColumn(this,i18n("Home Address Postal Code"));
    mAddressHomeState = new KImportColumn(this,i18n("Home Address State"));
    mAddressHomeCountry = new KImportColumn(this,i18n("Home Address Country"));

    mAddressBusinessCity = new KImportColumn(this,i18n("Business Address City"));
    mAddressBusinessStreet = new KImportColumn(this,i18n("Business Address Street"));
    mAddressBusinessZip = new KImportColumn(this,i18n("Business Address Postal Code"));
    mAddressBusinessState = new KImportColumn(this,i18n("Business Address State"));
    mAddressBusinessCountry = new KImportColumn(this,i18n("Business Address Country"));

    registerColumns();
}

void ContactImportDialog::convertRow()
{
    mEntry = new ContactEntry;

    mEntry->setFirstName(mFirstName->convert());
    mEntry->setLastName(mLastName->convert());
//      mEntry->setFullName(mFullName->convert());
    mEntry->setEmail(mEmail->convert());
    mEntry->setJobTitle(mJobTitle->convert());
    mEntry->setBusinessPhone(mPhoneBusiness->convert());
    mEntry->setHomePhone(mPhoneHome->convert());
    mEntry->setMobilePhone(mPhoneMobile->convert());
    mEntry->setHomeFax(mFaxHome->convert());
    mEntry->setBusinessFax(mFaxBusiness->convert());
    mEntry->setCompany(mCompany->convert());

    ContactEntry::Address *address = mEntry->getHomeAddress();
    address->setStreet(mAddressHomeStreet->convert());
    address->setCity(mAddressHomeCity->convert());
    address->setState(mAddressHomeState->convert());
    address->setZip(mAddressHomeZip->convert());
    address->setCountry(mAddressHomeCountry->convert());

    address = mEntry->getBusinessAddress();
    address->setStreet(mAddressBusinessStreet->convert());
    address->setCity(mAddressBusinessCity->convert());
    address->setState(mAddressBusinessState->convert());
    address->setZip(mAddressBusinessZip->convert());
    address->setCountry(mAddressBusinessCountry->convert());

    mList->insert(mEntry);
}

